==> surveyplat-proof-common-nfzd-1.0.0-20200930.123212-7-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzShxx.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2018/5/3.
 * 审核信息表
 */
@Table(name = "dcjz_shxx")
public class DcjzShxx {

    @Id
    //审核信息id
    private String shxxid;

    //图斑id
    private String xmid;

    //审核人员id
    private String shryid;

    //审核人员名称
    private String shrymc;

    //审核结果
    private String shjg;

    //审核时间
    private Date shsj;

    //审核说明
    private String shsm;

    //审核单位
    private String shdw;

    //备注
    private String bz;

    //审核类型
    private String shlx;

    //核查人员
    private String hcry;
    //退回单位
    private String thdw;

    //项目举证状态
    private String xmjzzt;

    public String getXmjzzt() {
        return xmjzzt;
    }

    public void setXmjzzt(String xmjzzt) {
        this.xmjzzt = xmjzzt;
    }

    public String getThdw() {
        return thdw;
    }

    public void setThdw(String thdw) {
        this.thdw = thdw;
    }

    public String getHcry() {
        return hcry;
    }

    public void setHcry(String hcry) {
        this.hcry = hcry;
    }

    public String getShxxid() {
        return shxxid;
    }

    public void setShxxid(String shxxid) {
        this.shxxid = shxxid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getShlx() {
        return shlx;
    }

    public void setShlx(String shlx) {
        this.shlx = shlx;
    }

    public String getShryid() {
        return shryid;
    }

    public void setShryid(String shryid) {
        this.shryid = shryid;
    }

    public String getShrymc() {
        return shrymc;
    }

    public void setShrymc(String shrymc) {
        this.shrymc = shrymc;
    }

    public String getShjg() {
        return shjg;
    }

    public void setShjg(String shjg) {
        this.shjg = shjg;
    }

    public Date getShsj() {
        return shsj;
    }

    public void setShsj(Date shsj) {
        this.shsj = shsj;
    }

    public String getShsm() {
        return shsm;
    }

    public void setShsm(String shsm) {
        this.shsm = shsm;
    }

    public String getShdw() {
        return shdw;
    }

    public void setShdw(String shdw) {
        this.shdw = shdw;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> surveyplat-proof-common-nfzd-1.0.0-20211019.031030-14-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzShxx.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2018/5/3.
 * 审核信息表
 */
@Table(name = "dcjz_shxx")
public class DcjzShxx {

    @Id
    //审核信息id
    private String shxxid;

    //图斑id
    private String xmid;

    //审核人员id
    private String shryid;

    //审核人员名称
    private String shrymc;

    //审核结果
    private String shjg;

    //审核时间
    private Date shsj;

    //审核说明
    private String shsm;

    //审核单位
    private String shdw;

    //备注
    private String bz;

    //审核类型
    private String shlx;

    //核查人员
    private String hcry;
    //退回单位
    private String thdw;

    //项目举证状态
    private String xmjzzt;

    //上次项目举证状态
    private String pxmjzzt;

    public String getPxmjzzt() {
        return pxmjzzt;
    }

    public void setPxmjzzt(String pxmjzzt) {
        this.pxmjzzt = pxmjzzt;
    }

    public String getXmjzzt() {
        return xmjzzt;
    }

    public void setXmjzzt(String xmjzzt) {
        this.xmjzzt = xmjzzt;
    }

    public String getThdw() {
        return thdw;
    }

    public void setThdw(String thdw) {
        this.thdw = thdw;
    }

    public String getHcry() {
        return hcry;
    }

    public void setHcry(String hcry) {
        this.hcry = hcry;
    }

    public String getShxxid() {
        return shxxid;
    }

    public void setShxxid(String shxxid) {
        this.shxxid = shxxid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getShlx() {
        return shlx;
    }

    public void setShlx(String shlx) {
        this.shlx = shlx;
    }

    public String getShryid() {
        return shryid;
    }

    public void setShryid(String shryid) {
        this.shryid = shryid;
    }

    public String getShrymc() {
        return shrymc;
    }

    public void setShrymc(String shrymc) {
        this.shrymc = shrymc;
    }

    public String getShjg() {
        return shjg;
    }

    public void setShjg(String shjg) {
        this.shjg = shjg;
    }

    public Date getShsj() {
        return shsj;
    }

    public void setShsj(Date shsj) {
        this.shsj = shsj;
    }

    public String getShsm() {
        return shsm;
    }

    public void setShsm(String shsm) {
        this.shsm = shsm;
    }

    public String getShdw() {
        return shdw;
    }

    public void setShdw(String shdw) {
        this.shdw = shdw;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
